# SPDX-FileCopyrightText: 2025 icalendar-anonymizer contributors
# SPDX-License-Identifier: AGPL-3.0-or-later

"""Test suite for icalendar-anonymizer.

Tests are organized by functionality:
- lib/: Library/core functionality tests
- cli/: Command-line interface tests
- web/: Web service tests
"""
